@@ -6,12 +6,13 @@ use MetaCPAN::Client;
 my $deps =
     MetaCPAN::Client->new->rev_deps('Hijk');
 
-my @output = (
-    map +{
-        name   => $_->name,
-        author => $_->author,
-    },
-    @{$deps},
-);
+my @output;
+
+while ( my $rel = $deps->next ) {
+    push @output => {
+        name   => $rel->name,
+        author => $rel->author,
+    };
+}
 
 p @output;
